@@ -635,7 +635,7 @@ void EditMultiItemWidget::edit(QTreeWidgetItem *i_pre) {
 		TransactionEditDialog *dialog = new TransactionEditDialog(b_extra, trans->type(), cur, trans->toAccount() == NULL, security, SECURITY_ALL_VALUES, security != NULL, budget, this, b_create_accounts);
 		dialog->editWidget->updateAccounts(account);
 		dialog->editWidget->setTransaction(trans);
-		if((trans->type() == TRANSACTION_TYPE_EXPENSE && ((Expense*) trans)->payee() == payeeEdit->text().trimmed()) || (trans->type() == TRANSACTION_TYPE_INCOME && ((Income*) trans)->payer() == payeeEdit->text().trimmed())) dialog->editWidget->setPayee("");
+		if(payeeEdit && ((trans->type() == TRANSACTION_TYPE_EXPENSE && ((Expense*) trans)->payee() == payeeEdit->text().trimmed()) || (trans->type() == TRANSACTION_TYPE_INCOME && ((Income*) trans)->payer() == payeeEdit->text().trimmed()))) dialog->editWidget->setPayee("");
 		if(dialog->exec() == QDialog::Accepted) {
 			if(dialog->editWidget->modifyTransaction(trans)) {
 				i->setTransaction(trans, cur, trans->toAccount() == NULL, dialog->editWidget->setQuoteChecked(), dialog->editWidget->quote());
